unit UnidadProcedimientos;

interface
  function leBoolINI (clave, cadena : string; defecto : boolean) : boolean;
  function leCadINI (clave, cadena : string; defecto : String) : String;
  function leNumINI (clave, cadena : string; defecto : Double) : Double;
  procedure esNumINI (clave, cadena : string; valor : Double);
  procedure esCadINI (clave, cadena : string; valor : String);
  procedure esBoolINI (clave, cadena : string; valor : Boolean);
  function llenarCadena (cadena : string; numero : integer; caracter : Char; derecha : Boolean) : string;
  function comprobarPermisos (accionRealizar : string; tipoUsuario : string; tabla : string) : boolean;
  procedure cargarConfiguracion ();
var
  vtAccion : string; //Accin a realizar: Nuevo, Modificar, Zoom
  vtCodigo : string; //Codigo del registro a ver
  vtCodigoUsuario : string; //Cdigo usuario inicio sesin
  vtTipoUsuario : string; //tipo de usuario inicio sesin
  vtClaveElegida : string; //clave elegida para seleccin
  vtCodigoTerceroFactura : String; //Cdigo de tercero para filtrar los pedidos para las facturas
  vtCodigoTemporal : string; //cdigo para pasar al aadir elementos desde otro lugar
  vtCodigoTemporal2 : string; //texto para pasar al aadir elementos desde otro lugar

  //valores para las etiquetas de los palets
  vtEtiquetaOrigen : string;
  vtEtiquetaNombreEmpresa : string;
  vtEtiquetaDireccionEmpresa : string;
  vtEtiquetaCP : string;
  vtEtiquetaTlfno : string;
  vtEtiquetaRIA : string;
  vtEtiquetaFecha : Boolean; //mostrar fecha de envasado del Palet en el cdigo de barras
  vtEtiquetaProducto : string;
  vtEtiquetaVariedad : string;
  vtEtiquetaCalibre : string;
  vtEtiquetaCategoria : string;
  vtEtiquetaTara : Double;
  vtEtiquetaTipoEnvase : string;
  vtEtiquetaCBTitulo : boolean; //para mostrar un ttulo en el Cdigo de barras
  vtEtiquetaCBTexto : string; //texto del ttulo a mostrar en el cdigo de barras
  vtCodigoFabricante : string; //valor por defecto al aadir producto - fabricante
  vtCodigoDistribuidor : string; //valor por defecto al aadir producto
  vtCodigoFormulacion : string; //valor por defecto al aadir producto
  vtCodigoProducto : string; //valor por defecto para producto en Ficha de control cuando no se selecciona una Operacin diferente a Tratamiento
  vtPlazoSeguridad : double; //valor por defecto al aadir producto
  vtParcelaAuto : boolean;
  vtFechaAlta : TDateTime;
  vtEntradasAlmacenNoFinalizadas : boolean; //Mostrar slo las Entradas de almacn no finalizadas en la seleccin
  vtMarcarEntradaFinalizada : boolean; //Marcar Entrada de Almacn como finalizada al seleccionarla en detalle de Palet
  vtGCAAgricultor : boolean; //generacin de cdigo automticamente
  vtGCAParcela : boolean;
  vtGCACultivo : boolean;
  vtGCACliente : boolean;
  vtGCAFichaControl : boolean;
  vtGCAFichaControlDetalle : boolean;
  vtGCAEntradaAlmacen : boolean;
  vtGCAPalet : boolean;
  vtGCADistribuidor : boolean;
  vtGCAProducto : boolean;
  vtGCAFabricante : boolean;
  vtGCAFormulacion : boolean;
  vtGCAPaletDetalle : boolean;

const
  //tablas
  vtTablaUsuario = 'Usuario';
  vtTablaUsuarioGrupo = 'UsuarioGrupo';
  vtTablaContador = 'Contador';
  vtTablaAgricultor = 'Agricultor';
  vtTablaFichaControl = 'FichaControl';
  vtTablaParcela = 'Parcela';
  vtTablaCliente = 'Cliente';
  vtTablaPalet = 'Palet';
  vtTablaPaletDetalle = 'PaletDetalle';
  vtTablaFichaControlDetalle = 'FichaControlDetalle';
  vtTablaProducto = 'Producto';
  vtTablaCultivo = 'Cultivo';
  vtTablaVariedad = 'Variedad';
  vtTablaFormulacion = 'Formulacion';
  vtTablaDistribuidor = 'Distribuidor';
  vtTablaFabricante = 'Fabricante';
  vtTablaProductoTipo = 'ProductoTipo';
  vtTablaProductoUnidad = 'ProductoUnidad';
  vtTablaEntradaAlmacen = 'EntradaAlmacen';
  vtTablaMatricula = 'Matricula';
  vtTablaEnvase = 'Envase';
  vtTablaEtiquetaProducto = 'EtiquetaProducto';
  vtTablaEtiquetaVariedad = 'EtiquetaVariedad';
  vtTablaEtiquetaCategoria = 'EtiquetaCategoria';
  vtTablaEtiquetaCalibre = 'EtiquetaCalibre';

  //nmeros para formularios de seleccin
  vtNumCultivo = 10;
  vtNumCliente = 20;
  vtNumFichaControl = 30;
  vtNumParcela = 40;
  vtNumAgricultor = 50;
  vtNumProducto = 60;
  vtNumFabricante = 70;
  vtNumDistribuidor = 80;
  vtNumFormulacion = 90;
  vtNumMateria = 100;
  vtNumEntradaAlmacen = 110;
  vtNumPalet = 120;
  vtNumUsuario = 200;
  vtNumUsuarioGrupo = 210;
  vtNumContador = 220;

  vtTamProveedor = 8;
  vtTamDistribuidor = 8;
  vtTamCliente = 4;
  vtTamCultivo = 4;
  vtTamEntradaAlmacen = 9;
  vtTamMateria = 9;
  vtTamProducto = 8;
  vtTamFichaControl = 8;
  vtTamFormulacion = 8;
  vtTamPalet = 8;


implementation

uses inifiles, sysutils;


//lee un valor booleano de un fichero INI
function leBoolINI (clave, cadena : string; defecto : boolean) : boolean;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := readbool (clave, cadena, defecto);
  finally
    free;
  end;
end;

//lee un valor string de un fichero INI
function leCadINI (clave, cadena : string; defecto : String) : String;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := ReadString (clave, cadena, defecto);
  finally
    free;
  end;
end;

//lee un valor float de un fichero INI
function leNumINI (clave, cadena : string; defecto : Double) : Double;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := ReadFloat (clave, cadena, defecto);
  finally
    free;
  end;
end;

                                         
//escribe un valor string en un fichero INI
procedure esCadINI (clave, cadena : string; valor : String);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteString (clave, cadena, valor);
  finally
    free;
  end;
end;

//escribe un valor float en un fichero INI
procedure esNumINI (clave, cadena : string; valor : Double);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteFloat (clave, cadena, valor);
  finally
    free;
  end;
end;

//escribe un valor boolean en un fichero INI
procedure esBoolINI (clave, cadena : string; valor : Boolean);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteBool (clave, cadena, valor);
  finally
    free;
  end;
end;


//llena una cadena con un nmero de caracteres determinado
function llenarCadena (cadena : string; numero : integer; caracter : Char; derecha : Boolean) : string;
begin
  while Length(cadena) < numero do
  begin
    if derecha then
      cadena := cadena + caracter
    else
      cadena := caracter + cadena;
  end;
  llenarCadena := cadena;
end;

//comprueba si un usuario determinado tiene permisos para realizar una accin determinada
function comprobarPermisos (accionRealizar : string; tipoUsuario : string; tabla : string) : boolean;
begin
  //Sin terminar
  comprobarPermisos := true;
end;

procedure cargarConfiguracion ();
begin
  vtEtiquetaOrigen := leCadINI('Etiquetas palets', 'Origen', '');
  vtEtiquetaNombreEmpresa := leCadINI('Etiquetas palets', 'Nombre', '');
  vtEtiquetaDireccionEmpresa := leCadINI('Etiquetas palets', 'Direccin', '');
  vtEtiquetaCP := leCadINI('Etiquetas palets', 'CP', '');
  vtEtiquetaTlfno := leCadINI('Etiquetas palets', 'Telfono', '');
  vtEtiquetaRIA := leCadINI('Etiquetas palets', 'RIA', '');
  vtEtiquetaFecha := leBoolINI('Etiquetas palets', 'Aadir fecha del Palet a la etiqueta', true);  
  vtEtiquetaProducto := leCadINI('Etiquetas palets', 'Producto', '');
  vtEtiquetaVariedad := leCadINI('Etiquetas palets', 'Variedad', '');
  vtEtiquetaCalibre := leCadINI('Etiquetas palets', 'Calibre', '');
  vtEtiquetaCategoria := leCadINI('Etiquetas palets', 'Categoria', '');
  vtEtiquetaTara :=  leNumINI('Etiquetas palets', 'Tara envase', 0);
  vtEtiquetaTipoEnvase := leCadINI('Etiquetas palets', 'Tipo envase', '');
  vtCodigoFabricante := leCadINI('Valores por defecto', 'Productos - Fabricante', '');
  vtCodigoDistribuidor := leCadINI('Valores por defecto', 'Productos - Distribuidor', '');
  vtCodigoFormulacion := leCadINI('Valores por defecto', 'Productos - Formulacin', '');
  vtCodigoProducto := leCadINI('Valores por defecto', 'Productos - Producto', '');  
  vtPlazoSeguridad := leNumINI('Valores por defecto', 'Productos - Plazo seguridad', 0);
  vtParcelaAuto := leBoolINI('Valores por defecto', 'Parcela automtica', false);
  vtEntradasAlmacenNoFinalizadas :=   leBoolINI('Cargar datos', 'Entradas de almacn no finalizadas', true);
  vtMarcarEntradaFinalizada := leBoolINI('Cargar datos', 'Marcar entrada como Finalizada', true);
  vtGCAAgricultor := leBoolINI('Cdigo automtico', 'Agricultor', true);
  vtGCAParcela := leBoolINI('Cdigo automtico', 'Parcela', true);
  vtGCACultivo := leBoolINI('Cdigo automtico', 'Cultivo', true);
  vtGCACliente := leBoolINI('Cdigo automtico', 'Cliente', true);
  vtGCAFichaControl := leBoolINI('Cdigo automtico', 'Ficha control', true);
  vtGCAFichaControlDetalle := leBoolINI('Cdigo automtico', 'Ficha control detalle', true);
  vtGCAEntradaAlmacen :=  leBoolINI('Cdigo automtico', 'Entrada almacn', true);
  vtGCAPalet := leBoolINI('Cdigo automtico', 'Palet', true);
  vtGCADistribuidor := leBoolINI('Cdigo automtico', 'Distribuidor', true);
  vtGCAProducto := leBoolINI('Cdigo automtico', 'Producto', true);
  vtGCAFabricante := leBoolINI('Cdigo automtico', 'Fabricante', true);
  vtGCAFormulacion := leBoolINI('Cdigo automtico', 'Formulacin', true);
  vtGCAPaletDetalle := leBoolINI('Cdigo automtico', 'Palet detalle', true);  
end;


end.
